@@ -7,7 +7,7 @@ from pyramid.httpexceptions import HTTPNotFound
 from pyramid.session import UnencryptedCookieSessionFactoryConfig
 from pyramid.view import view_config
 
-from paste.httpserver import serve
+from wsgiref.simple_server import make_server
 
 try:
     import sqlalchemy
@@ -27,11 +27,15 @@ def exc(request):
 def notfound(request):
     raise HTTPNotFound()
 
+@view_config(context=HTTPNotFound, renderer='notfound.mako')
+def notfound_view(request):
+    return {}
+
 @view_config(route_name='test_page', renderer='index.mako')
 def test_page(request):
     title = 'Pyramid Debugtoolbar'
     log.info(title)
-    return {'title': title}
+    return {'title': title, 'show_sqla_link': bool(sqlalchemy)}
 
 @view_config(route_name='test_redirect')
 def test_redirect(request):
@@ -75,4 +79,5 @@ if __name__ == '__main__':
     if sqlalchemy:
         config.include('sqla')
     config.include('pyramid_debugtoolbar')
-    serve(config.make_wsgi_app(), host='0.0.0.0')
+    httpd = make_server('', 8080, config.make_wsgi_app())
+    httpd.serve_forever()
