@@ -19,6 +19,12 @@ from tokenize import TokenError
 from pyramid.decorator import reify
 from pyramid.renderers import render
 
+from pyramid_debugtoolbar.compat import text_type
+from pyramid_debugtoolbar.compat import string_types
+from pyramid_debugtoolbar.compat import text_
+from pyramid_debugtoolbar.compat import native_
+from pyramid_debugtoolbar.compat import exec_
+from pyramid_debugtoolbar.compat import xrange_
 from pyramid_debugtoolbar.console import Console
 from pyramid_debugtoolbar.utils import escape
 from pyramid_debugtoolbar.utils import STATIC_PATH
@@ -36,23 +42,23 @@ try:
 except NameError:
     pass
 
-FRAME_HTML = u'''\
+FRAME_HTML = text_('''\
 <div class="frame" id="frame-%(id)d">
   <h4>File <cite class="filename">"%(filename)s"</cite>,
       line <em class="line">%(lineno)s</em>,
       in <code class="function">%(function_name)s</code></h4>
   <pre>%(current_line)s</pre>
 </div>
-'''
+''')
 
-SOURCE_TABLE_HTML = u'<table class=source>%s</table>'
+SOURCE_TABLE_HTML = text_('<table class=source>%s</table>')
 
-SOURCE_LINE_HTML = u'''\
+SOURCE_LINE_HTML = text_('''\
 <tr class="%(classes)s">
   <td class=lineno>%(lineno)s</td>
   <td>%(code)s</td>
 </tr>
-'''
+''')
 
 
 def get_current_traceback(ignore_system_exceptions=False,
@@ -72,7 +78,7 @@ def get_traceback(info, ignore_system_exceptions=False,
     exc_type, exc_value, tb = info
     if ignore_system_exceptions and exc_type in system_exceptions:
         raise
-    for x in xrange(skip):
+    for x in xrange_(skip):
         if tb.tb_next is None:
             break
         tb = tb.tb_next
@@ -103,7 +109,7 @@ class Line(object):
 
     def render(self):
         return SOURCE_LINE_HTML % {
-            'classes':      u' '.join(self.classes),
+            'classes':      text_(' '.join(self.classes)),
             'lineno':       self.lineno,
             'code':         escape(self.code)
         }
@@ -173,7 +179,7 @@ class Traceback(object):
     def exception(self):
         """String representation of the exception."""
         buf = traceback.format_exception_only(self.exc_type, self.exc_value)
-        return ''.join(buf).strip().decode('utf-8', 'replace')
+        return native_(''.join(buf).strip(), 'utf-8', 'replace')
     exception = property(exception)
 
     def log(self, logfile=None):
@@ -199,25 +205,27 @@ class Traceback(object):
 
         if include_title:
             if self.is_syntax_error:
-                title = u'Syntax Error'
+                title = text_('Syntax Error')
             else:
-                title = u'Traceback <em>(most recent call last)</em>:'
+                title = text_('Traceback <em>(most recent call last)</em>:')
 
         for frame in self.frames:
-            frames.append(u'<li%s>%s' % (
-                frame.info and u' title="%s"' % escape(frame.info) or u'',
+            frames.append(
+                text_('<li%s>%s') % (
+                frame.info and text_(' title="%s"' % escape(frame.info)) or
+                    text_(''),
                 frame.render()
             ))
 
         if self.is_syntax_error:
-            description_wrapper = u'<pre class=syntaxerror>%s</pre>'
+            description_wrapper = text_('<pre class=syntaxerror>%s</pre>')
         else:
-            description_wrapper = u'<blockquote>%s</blockquote>'
+            description_wrapper = text_('<blockquote>%s</blockquote>')
 
         vars = {
-            'classes':      u' '.join(classes),
-            'title':        title and u'<h3>%s</h3>' % title or u'',
-            'frames':       u'\n'.join(frames),
+            'classes':      text_(' '.join(classes)),
+            'title':        title and text_('<h3>%s</h3>' % title) or text_(''),
+            'frames':       text_('\n'.join(frames)),
             'description':  description_wrapper % escape(self.exception),
         }
         return render('pyramid_debugtoolbar:templates/exception_summary.jinja2',
@@ -253,19 +261,19 @@ class Traceback(object):
 
     def generate_plaintext_traceback(self):
         """Like the plaintext attribute but returns a generator"""
-        yield u'Traceback (most recent call last):'
+        yield text_('Traceback (most recent call last):')
         for frame in self.frames:
-            yield u'  File "%s", line %s, in %s' % (
+            yield text_('  File "%s", line %s, in %s' % (
                 frame.filename,
                 frame.lineno,
                 frame.function_name
-            )
-            yield u'    ' + frame.current_line.strip()
+            ))
+            yield text_('    ' + frame.current_line.strip())
         yield self.exception
 
     @reify
     def plaintext(self):
-        return u'\n'.join(self.generate_plaintext_traceback())
+        return text_('\n'.join(self.generate_plaintext_traceback()))
 
     id = property(lambda x: id(x))
 
@@ -339,18 +347,18 @@ class Frame(object):
 
     def render_source(self):
         """Render the sourcecode."""
-        return SOURCE_TABLE_HTML % u'\n'.join(line.render() for line in
-                                              self.get_annotated_lines())
+        return SOURCE_TABLE_HTML % text_('\n'.join(line.render() for line in
+                                              self.get_annotated_lines()))
 
     def eval(self, code, mode='single'):
         """Evaluate code in the context of the frame."""
-        if isinstance(code, basestring):
-            if isinstance(code, unicode):
+        if isinstance(code, string_types):
+            if isinstance(code, text_type):
                 code = UTF8_COOKIE + code.encode('utf-8')
             code = compile(code, '<interactive>', mode)
         if mode != 'exec':
             return eval(code, self.globals, self.locals)
-        exec code in self.globals, self.locals
+        exec_(code, self.globals, self.locals)
 
     @reify
     def sourcelines(self):
@@ -370,7 +378,7 @@ class Frame(object):
 
         if source is None:
             try:
-                f = file(self.filename)
+                f = open(self.filename)
             except IOError:
                 return []
             try:
@@ -379,7 +387,7 @@ class Frame(object):
                 f.close()
 
         # already unicode?  return right away
-        if isinstance(source, unicode):
+        if isinstance(source, text_type):
             return source.splitlines()
 
         # yes. it should be ascii, but we don't want to reject too many
@@ -409,7 +417,7 @@ class Frame(object):
         try:
             return self.sourcelines[self.lineno - 1]
         except IndexError:
-            return u''
+            return text_('')
 
     @reify
     def console(self):
