@@ -3,6 +3,8 @@ from pyramid.request import Request
 from pyramid.response import Response
 from pyramid import testing
 
+from pyramid_debugtoolbar.compat import bytes_
+
 class DebugToolbarTests(unittest.TestCase):
     def setUp(self):
         self.config = testing.setUp()
@@ -16,7 +18,7 @@ class DebugToolbarTests(unittest.TestCase):
 
     def test_ctor_panel_is_up(self):
         request = Request.blank('/')
-        request.cookies['p_dt_active'] = 'id'
+        request.environ['HTTP_COOKIE'] = 'p_dt_active="id"'
         toolbar = self._makeOne(request, [DummyPanelWithContent])
         self.assertEqual(len(toolbar.panels), 1)
         panel = toolbar.panels[0]
@@ -25,7 +27,7 @@ class DebugToolbarTests(unittest.TestCase):
 
     def test_ctor_panel_has_content(self):
         request = Request.blank('/')
-        request.cookies['p_dt_active'] = 'id'
+        request.environ['HTTP_COOKIE'] = 'p_dt_active="id"'
         toolbar = self._makeOne(request, [DummyPanelWithContent])
         self.assertEqual(len(toolbar.panels), 1)
         panel = toolbar.panels[0]
@@ -54,7 +56,25 @@ class DebugToolbarTests(unittest.TestCase):
         toolbar = self._makeOne(request, [DummyPanel])
         toolbar.process_response(response)
         self.assertTrue(response.processed)
-        self.failUnless('div id="pDebug"' in response.app_iter[0])
+        self.failUnless(bytes_('div id="pDebug"') in response.app_iter[0])
+
+    def test_passing_of_button_style(self):
+        from pyramid_debugtoolbar.utils import ROOT_ROUTE_NAME
+        from pyramid_debugtoolbar.utils import STATIC_PATH
+        self.config.include('pyramid_jinja2')
+        self.config.add_static_view('_debugtoolbar/static',
+                                    STATIC_PATH)
+        self.config.add_route(ROOT_ROUTE_NAME, '/_debugtoolbar')
+        self.config.registry.settings['debugtoolbar.button_style'] = \
+            'top:120px;zoom:50%'
+        response = Response('<body></body>')
+        response.content_type = 'text/html'
+        request = Request.blank('/')
+        request.registry = self.config.registry
+        toolbar = self._makeOne(request, [DummyPanel])
+        toolbar.process_response(response)
+        self.assertTrue(response.processed)
+        self.failUnless(bytes_('top:120px;zoom:50%') in response.app_iter[0])
 
 class Test_beforerender_subscriber(unittest.TestCase):
     def setUp(self):
@@ -163,6 +183,7 @@ class Test_toolbar_handler(unittest.TestCase):
         request = Request.blank('/')
         def handler(request):
             raise NotImplementedError
+        request.registry = self.config.registry
         self.assertRaises(NotImplementedError, self._callFUT, request, handler)
 
     def test_it_raises_exception_intercept_exc(self):
@@ -172,6 +193,7 @@ class Test_toolbar_handler(unittest.TestCase):
         self.config.registry.settings['debugtoolbar.intercept_exc'] = True
         self.config.registry.settings['debugtoolbar.secret'] = 'abc'
         self.config.add_route('debugtoolbar.exception', '/exception')
+        request.registry = self.config.registry
         response = self._callFUT(request, handler)
         self.assertEqual(len(request.exc_history.tracebacks), 1)
         self.assertFalse(hasattr(request, 'debug_toolbar'))
@@ -180,6 +202,7 @@ class Test_toolbar_handler(unittest.TestCase):
     def test_it_intercept_redirect_nonredirect_code(self):
         request = Request.blank('/')
         self.config.registry.settings['debugtoolbar.intercept_redirects'] = True
+        request.registry = self.config.registry
         result = self._callFUT(request)
         self.assertTrue(result is self.response)
 
@@ -189,6 +212,7 @@ class Test_toolbar_handler(unittest.TestCase):
         def handler(request):
             return response
         request = Request.blank('/')
+        request.registry = self.config.registry
         self.config.registry.settings['debugtoolbar.intercept_redirects'] = True
         result = self._callFUT(request, handler)
         self.assertTrue(result is response)
