@@ -1,11 +1,14 @@
+import binascii
 import sys
 import os
-from urllib import unquote
 
 from pyramid.renderers import render
 from pyramid.threadlocal import get_current_request
 from pyramid.response import Response
 from pyramid_debugtoolbar.tbtools import get_traceback
+from pyramid_debugtoolbar.compat import url_unquote
+from pyramid_debugtoolbar.compat import bytes_
+from pyramid_debugtoolbar.compat import text_
 from pyramid_debugtoolbar.utils import get_setting
 from pyramid_debugtoolbar.utils import replace_insensitive
 from pyramid_debugtoolbar.utils import STATIC_PATH
@@ -21,7 +24,7 @@ class DebugToolbar(object):
     def __init__(self, request, panel_classes):
         self.request = request
         self.panels = []
-        p_dt_active = unquote(self.request.cookies.get('p_dt_active', ''))
+        p_dt_active = url_unquote(self.request.cookies.get('p_dt_active', ''))
         activated = p_dt_active.split(';')
         for panel_class in panel_classes:
             panel_inst = panel_class(request)
@@ -43,20 +46,24 @@ class DebugToolbar(object):
         if response.content_type in self.html_types:
             static_path = request.static_url(STATIC_PATH)
             root_path = request.route_url(ROOT_ROUTE_NAME)
+            button_style = get_setting(request.registry.settings,
+                                       'button_style', '')
             vars = {'panels': self.panels, 'static_path': static_path,
-                    'root_path': root_path}
+                    'root_path': root_path, 'button_style': button_style}
             toolbar_html = render(
                 'pyramid_debugtoolbar:templates/toolbar.jinja2',
                 vars, request=request)
             response_html = response.body
             toolbar_html = toolbar_html.encode(response.charset or 'utf-8')
-            body = replace_insensitive(response_html, '</body>',
-                                       toolbar_html + '</body>')
+            body = replace_insensitive(
+                response_html, bytes_('</body>'),
+                toolbar_html + bytes_('</body>')
+                )
             response.app_iter = [body]
 
 class ExceptionHistory(object):
     def __init__(self):
-        self.token = os.urandom(10).encode('hex')
+        self.token = text_(binascii.hexlify(os.urandom(10)))
         self.frames = {}
         self.tracebacks = {}
 
