@@ -5,6 +5,11 @@ from logging import getLogger
 from pyramid.util import DottedNameResolver
 from pyramid.settings import asbool
 
+from pyramid_debugtoolbar.compat import binary_type
+from pyramid_debugtoolbar.compat import text_type
+from pyramid_debugtoolbar.compat import string_types
+
+
 try:
     from pygments import highlight
     from pygments.formatters import HtmlFormatter
@@ -74,10 +79,10 @@ def escape(s, quote=False):
     """
     if s is None:
         return ''
-    elif hasattr(s, '__html__'):
+    if hasattr(s, '__html__'):
         return s.__html__()
-    elif not isinstance(s, basestring):
-        s = unicode(s)
+    if not isinstance(s, (text_type, binary_type)):
+        s = text_type(s)
     s = s.replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
     if quote:
         s = s.replace('"', "&quot;")
@@ -97,7 +102,7 @@ def replace_insensitive(string, target, replacement):
 resolver = DottedNameResolver(None)
 
 def as_cr_separated_list(value):
-    if isinstance(value, basestring):
+    if isinstance(value, string_types):
         value = filter(None, [x.strip() for x in value.splitlines()])
     return value
 
@@ -118,7 +123,7 @@ def as_globals_list(value):
     return L
 
 def as_display_debug_or_false(value):
-    if isinstance(value, basestring):
+    if isinstance(value, string_types):
         val = value.lower().strip()
         if val in ('display', 'debug'):
             return val
